/*////////////////////////////////////////////////////////////////////

	規則音声合成エンジン AquesTalk10 iOS

	音声記号列から音声波形データを生成、または、サウンドデバイスに出力する	

	COPYRIGHT (C) 2017 AQUEST CORP.

	@date	2017/10/14	N.Yamazaki	Creation
	
//////////////////////////////////////////////////////////////////////*/
#if !defined(_AQUESTALKDA_H_)
#define c
#ifdef __cplusplus
extern "C"{
#endif

// 声質パラメータ
typedef struct _AQTK_VOICE_ {
	int bas;	// 基本素片 F1E/F2E/M1E (0/1/2)
	int spd;	// 話速 	50-300 default:100
	int vol;	// 音量 	0-300 default:100
	int pit;	// 高さ 	20-200 default:基本素片に依存
	int acc;	// アクセント 0-200 default:基本素片に依存
	int lmd;	// 音程１ 	0-200 default:100
	int fsc;	// 音程２(サンプリング周波数) 50-200 default:100
} AQTK_VOICE;

enum VoiceBase { F1E =0, F2E, M1E }; // 基本素片

// プリセット声種                 bas  spd  vol  pit  acc  lmd  fsc
const AQTK_VOICE	gVoice_F1 = { F1E, 100, 100, 100, 100, 100, 100}; // 女声 F1
const AQTK_VOICE	gVoice_F2 = { F2E, 100, 100,  77, 150, 100, 100}; // 女声 F2
const AQTK_VOICE	gVoice_F3 = { F1E,  80, 100, 100, 100,  61, 148}; // 女声 F3
const AQTK_VOICE	gVoice_M1 = { M1E, 100, 100,  30, 100, 100, 100}; // 男声 M1
const AQTK_VOICE	gVoice_M2 = { M1E, 105, 100,  45, 130, 120, 100}; // 男声 M2
const AQTK_VOICE	gVoice_R1 = { M1E, 100, 100,  30,  20, 190, 100}; // ロボット R1
const AQTK_VOICE	gVoice_R2 = { F2E,  70, 100,  50,  50,  50, 180}; // ロボット R2

/////////////////////////////////////////////
//!	音声記号列から音声波形を生成
//!	音声波形データは内部で領域確保される。
//!	音声波形データの解放は本関数の呼び出し側でAquesTalk_FreeWave()にて行う
//! pParam[in]	声質パラメータ (AQTK_VOICE構造体のアドレス)
//! koe[in]		音声記号列（SJIS NULL終端）
//!	pSize[out]	生成した音声データのサイズ[byte]（エラーの場合はエラーコードが返る）
//!	return	WAVフォーマットの音声データの先頭アドレス。エラー時はNULLが返る
unsigned char * AquesTalk_Synthe(const AQTK_VOICE *pParam, const char *koe, int *pSize);

//! koeUtf8[in]	音声記号列（UTF8 NULL終端）
unsigned char * AquesTalk_Synthe_Utf8(const AQTK_VOICE *pParam, const char *koeUtf8, int *pSize);

/////////////////////////////////////////////
//!	音声データの領域を開放
//!	  wav[in]		AquesTalk_Synthe()で返されたアドレスを指定
void AquesTalk_FreeWave(unsigned char *wav);

	
/////////////////////////////////////////////
//!	開発ライセンスキー設定
//!	音声波形を生成する前に一度呼び出す。
//!	これにより評価版の制限がなくなる。
//!	param  key[in]		ライセンスキーを指定
//!	return	ライセンスキーが正しければ0、正しくなければ1が返る
//! *キーの解析を防ぐため不正なキーでも0を返す場合がある。このとき制限は解除されない。
int AquesTalk_SetDevKey(const char *key);

/////////////////////////////////////////////
//!	使用ライセンスキー設定
//!	音声波形を生成する前に一度呼び出す。
//!	以降、合成音声データに含まれる透かしが、使用ライセンス無しから取得済みに変化する
//!	param  key[in]		ライセンスキーを指定
//!	return	ライセンスキーが正しければ0、正しくなければ1が返る
//! *キーの解析を防ぐため不正なキーでも0を返す場合がある。この場合、ライセンス無のままである。
int AquesTalk_SetUsrKey(const char *key);



/////////////////////////////////////////////
//!	音声を合成してサウンドデバイスに出力（同期タイプ）
//!	音声の再生が終了するまで戻らない
//! 	pParam[in]	声質パラメータ (AQTK_VOICE構造体のアドレス)
//! 	koe[in]		音声記号列（SJIS NULL終端）
//! 	koeUtf8[in]		音声記号列（UTF8 NULL終端）
//!	return	0:正常終了　それ以外：エラーコード
int  AquesTalkDa_PlaySync(const AQTK_VOICE *pParam, const char *koe);
int  AquesTalkDa_PlaySync_Utf8(const AQTK_VOICE *pParam, const char *koeUtf8);



////////////////////////////////////////////////////////////////////////
//  以下、非同期タイプの関数
////////////////////////////////////////////////////////////////////////
typedef void		*H_AQTKDA;	// 音声合成エンジンのハンドル 同期タイプの関数で使用する

/////////////////////////////////////////////
//!	音声合成エンジンのインスタンスを生成（非同期タイプ）
//! return	音声合成エンジンのハンドルを返す
H_AQTKDA  AquesTalkDa_Create();

/////////////////////////////////////////////
//!	音声合成エンジンのインスタンスを解放（非同期タイプ）
//! 	hMe[in]		音声合成エンジンのハンドル AquesTalkDa_Create()で生成
void  AquesTalkDa_Release(H_AQTKDA hMe);

/////////////////////////////////////////////
//!	音声を合成して出力（非同期タイプ）
//!	音声波形生成後に、すぐに戻る
//!	notificationを指定すると、再生終了後に指定したイベントが通知される。
//!		
//! 	hMe[in]		音声合成エンジンのハンドル AquesTalkDa_Create()で生成
//! 	pParam[in]	声質パラメータ (AQTK_VOICE構造体のアドレス)
//! 	koe[in]		音声記号列（SJIS NULL終端）
//! 	koeUtf8[in]		音声記号列（UTF8 NULL終端）
//! 	notification[in]	再生終了イベントの指定。イベント通知不要のときはnilを指定します。
//!	return	0:正常終了　それ以外：エラーコード
int  AquesTalkDa_Play(H_AQTKDA hMe, const AQTK_VOICE *pParam, const char *koe, NSNotification* notification);
int  AquesTalkDa_Play_Utf8(H_AQTKDA hMe, const AQTK_VOICE *pParam, const char *koeUtf8, NSNotification* notification);

/////////////////////////////////////////////
//!	再生の中止 
//! AquesTalkDa_Play()で再生中に、再生を中断する。
//!	再生中(再生待ちを含む）であり、かつ、notificationが指定されていたなら、
//! 再生終了イベントが通知される。
//! 	hMe[in]		音声合成エンジンのハンドル AquesTalkDa_Create()で生成
void  AquesTalkDa_Stop(H_AQTKDA hMe);

/////////////////////////////////////////////
//!	再生中か否か
//! 	hMe[in]		音声合成エンジンのハンドル AquesTalkDa_Create()で生成
//! return 1:再生中 0:再生中でない
int  AquesTalkDa_IsPlay(H_AQTKDA hMe);


#ifdef __cplusplus
}
#endif
#endif // !defined(_AQUESTALKDA_H_)
//  ----------------------------------------------------------------------
// !  Copyright AQUEST Corp. 2006- .  All Rights Reserved.                !
// !  An unpublished and CONFIDENTIAL work.  Reproduction, adaptation, or !
// !  translation without prior written permission is prohibited except   !
// !  as allowed under the copyright laws.                                !
//  ----------------------------------------------------------------------
